# ListRoleToRuleEntries

The response object for a `list_role_to_rule_entries` operation. 
## Properties
Name | Type | Description | Notes
------------ | ------------- | ------------- | -------------
**limit** | **int** | The maximum number of netries that could be returned in the response.  | 
**role_to_rule_entries** | [**list[RoleToRuleEntry]**](RoleToRuleEntry.md) | The entries matching the search criteria | [optional] 

[[Back to Model list]](../README.md#documentation-for-models) [[Back to API list]](../README.md#documentation-for-api-endpoints) [[Back to README]](../README.md)


